@@ -35,12 +35,11 @@ module I18n
         def store_translations(locale, data, options = EMPTY_HASH)
           if I18n.enforce_available_locales &&
             I18n.available_locales_initialized? &&
-            !I18n.available_locales.include?(locale.to_sym) &&
-            !I18n.available_locales.include?(locale.to_s)
+            !I18n.locale_available?(locale)
             return data
           end
           locale = locale.to_sym
-          translations[locale] ||= {}
+          translations[locale] ||= Concurrent::Hash.new
           data = data.deep_symbolize_keys
           translations[locale].deep_merge!(data)
         end
@@ -71,7 +70,7 @@ module I18n
           # call `init_translations`
           init_translations if do_init && !initialized?
 
-          @translations ||= {}
+          @translations ||= Concurrent::Hash.new { |h, k| h[k] = Concurrent::Hash.new }
         end
 
       protected
